@@ -1,5 +1,5 @@
 import logging
-from typing import Tuple, Any, Optional, Callable, ClassVar
+from typing import Tuple, Any, Optional, Callable, ClassVar, TypeVar, cast, Dict
 
 import jwt
 from django.conf import settings
@@ -10,16 +10,24 @@ from rest_framework.exceptions import AuthenticationFailed
 
 log = logging.getLogger(__name__)
 
+_T = TypeVar("_T")
+
 
 class PyJWTAuthentication(TokenAuthentication):
     keyword = "Bearer"
 
     _jwks_client: ClassVar[Optional[jwt.PyJWKClient]] = None
 
+    @staticmethod
+    def get_setting(name: str, default: _T) -> _T:
+        return getattr(settings, name, default)
+
     @classmethod
     def get_jwks_client(cls) -> jwt.PyJWKClient:
         if not cls._jwks_client:
-            cls._jwks_client = jwt.PyJWKClient(settings.DRF_PYJWT["JWKS_URI"])
+            cls._jwks_client = jwt.PyJWKClient(
+                cls.get_setting("DRF_PYJWT_JWKS_URI", "")
+            )
         return cls._jwks_client
 
     @classmethod
@@ -40,27 +48,15 @@ class PyJWTAuthentication(TokenAuthentication):
         return jwt.decode(
             jwt=token,
             key=signing_key.key,
-            algorithms=self.get_algorithms(),
-            options=self.get_options(),
-            **self.get_kwargs(),
+            algorithms=self.get_setting("DRF_PYJWT_ALGORITHMS", ["RS256"]),
+            options=self.get_setting("DRF_PYJWT_OPTIONS", {}),
+            **cast(Dict[str, Any], self.get_setting("DRF_PYJWT_KWARGS", {})),
         )
 
-    @staticmethod
-    def lookup_user(token: dict) -> Optional[AbstractBaseUser]:
-        if import_str := settings.DRF_PYJWT.get("LOOKUP_USER"):
+    @classmethod
+    def lookup_user(cls, token: dict) -> Optional[AbstractBaseUser]:
+        if import_str := cls.get_setting("DRF_PYJWT_LOOKUP_USER", ""):
             _lookup_user: Callable[[dict], Optional[AbstractBaseUser]]
             _lookup_user = import_string(import_str)
             return _lookup_user(token)
         return None
-
-    @staticmethod
-    def get_algorithms() -> Optional[list[str]]:
-        return settings.DRF_PYJWT.get("ALGORITHMS")
-
-    @staticmethod
-    def get_options() -> Optional[dict]:
-        return settings.DRF_PYJWT.get("OPTIONS")
-
-    @staticmethod
-    def get_kwargs() -> dict:
-        return settings.DRF_PYJWT.get("KWARGS") or {}
